<?php
namespace app\components\modules\payment;

use framework\request\Request;
use framework\helpers\Html;
use app\models\Trans;

class GateWayApi
{	
	private $apiUrl = 'http://behbank.com/ws';
	private $gatewayUrl = 'http://behbank.com/payment';
	public function paymentRequest($params){
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $this->apiUrl.'/payments/request.json');
        curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type' => 'application/json'));
        curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($params));
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        $response = json_decode(curl_exec($curl));
        curl_close($curl);
        if(isset($response->status) && $response->status == 1 ){
            return array(
                'status'    		=>  true,
                'paymentNumber'     =>  $response->paymentNumber,
            );
        }else{
            return array(
                'status'    =>  false,
                'message'   =>  $response->message,
            );
        }
    }
    public function paymentVerify($params){
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $this->apiUrl.'/payments/verify.json');
        curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type' => 'application/json'));
        curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode( $params ));
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        $response = json_decode(curl_exec($curl));
        curl_close($curl);
        if(isset($response->status) && $response->status == 1){
            return array(
                'status'    =>  true,
            );
        }else{
            return array(
                'status'    =>  false,
                'message'   =>  $response->message,
            );
        }
    }
    public function paymentGateway($paymentNumber){
        $paymentUrl = $this->gatewayUrl.'/'.$paymentNumber;
        if ( ! headers_sent() ) {
            header('Location: ' . $paymentUrl );
            die;
        }
        die('<script type="text/javascript">window.location="' .$paymentUrl. '";</script>');
    }
	public function getGatewayUrl($paymentNumber)
	{
		return $this->gatewayUrl.'/'.$paymentNumber;
	}
}

class BehBank extends Payment
{
	public function request($id, $au, $price, $module, $product)
	{
		//order data
		$product = is_object($product) ? ( (array) $product ) : $product;
		$productsName = is_array($product) ? implode( '-' , $product ) : $product;
		$trans = Trans::model()->getTrans($au);
		$userEmail 	= isset($trans->transEmail) ? Html::escape($trans->transEmail) : '';
		$userEmail 	= !filter_var($userEmail, FILTER_VALIDATE_EMAIL) === false ? $userEmail : '';
		$userMobile = isset($trans->transMobile) ? Html::escape($trans->transMobile) : '';
		$userMobile = preg_match('/^09[0-9]{9}/i', $userMobile) ? $userMobile : '';
		$description = isset($trans->transContent) ? nl2br(Html::escape($trans->transContent)) : '-';

		//request
		$gateway = new GateWayApi();
		$params = array(
			'merchantCode'  => $module['merchant']['value'],
			'amount'        => $this->getRial($price),
			'callBackUrl'   => $this->getCallbackUrl($au),
			'invoiceNumber' => $id,
			'payerEmail'	=> $userEmail,
			'payerMobile'	=> $userMobile,
			'description'	=> $description.' - محصولات: '.$productsName,
		);
		$request = $gateway->paymentRequest($params);
		if ($request['status'] == false)
		{
			$this->setFlash('danger', 'متاسفانه مشکلی وجود دارد - '.$request['message']);
			return false;
		}
		$this->updateAu($id, $request['paymentNumber']);
		$this->redirect($gateway->getGatewayUrl($request['paymentNumber']));
	}

	public function verify($id, $au, $price, $module, $product)
	{

		if (Request::isPost('status') && Request::getPost('status') == 1)
		{
			$gateway = new GateWayApi();
			$params = array(
				'merchantCode'  => $module['merchant']['value'],
				'paymentNumber' => Request::getPost('paymentNumber'),
			);
			$request = $gateway->paymentVerify($params);
			if ($request['status'])
			{
				return array('au' => Request::getPost('paymentNumber'));
			}
			else
			{
				$this->setFlash('danger', 'متاسفانه مشکلی وجود دارد - '.$request['message']);
				return false;
			}
		}
		else
		{
			$this->setFlash('danger', 'پرداخت انجام نشد');
			return false;
		}
	}

	public function fields()
	{
		return array('merchant' => array('label' => 'مرچنت کد', 'value' => ''));
	}
}

?>